@@ -35,9 +35,9 @@ MD_FLAGS = [
     "MONGOC_MD_FLAG_HAVE_SCHED_GETCPU",
     "MONGOC_MD_FLAG_ENABLE_SHM_COUNTERS",
     "MONGOC_MD_FLAG_TRACE",
-    "MONGOC_MD_FLAG_ENABLE_ICU",
     "MONGOC_MD_FLAG_ENABLE_CLIENT_SIDE_ENCRYPTION",
-    "MONGOC_MD_FLAG_ENABLE_MONGODB_AWS_AUTH"
+    "MONGOC_MD_FLAG_ENABLE_MONGODB_AWS_AUTH",
+    "MONGOC_MD_FLAG_ENABLE_SRV",
 ]
 
 def main():
