@@ -61,8 +61,6 @@ bool
 test_framework_getenv_bool (const char *name);
 int64_t
 test_framework_getenv_int64 (const char *name, int64_t default_value);
-bool
-test_framework_setenv (const char *name, const char *value);
 char *
 test_framework_get_host (void);
 uint16_t
@@ -191,8 +189,6 @@ test_framework_skip_if_not_single (void);
 int
 test_framework_skip_if_offline (void);
 int
-test_framework_skip_if_rhel8_zseries (void);
-int
 test_framework_skip_if_slow (void);
 int
 test_framework_skip_if_slow_or_live (void);
@@ -216,6 +212,8 @@ WIRE_VERSION_CHECK_DECLS (17)
 WIRE_VERSION_CHECK_DECLS (19)
 /* wire version 21 begins with the 7.0 release. */
 WIRE_VERSION_CHECK_DECLS (21)
+/* wire version 22 begins with the 7.1 release. */
+WIRE_VERSION_CHECK_DECLS (22)
 
 #undef WIRE_VERSION_CHECK_DECLS
 
@@ -259,9 +257,6 @@ test_framework_skip_if_no_failpoint (void);
 int
 test_framework_skip_if_no_client_side_encryption (void);
 
-int
-test_framework_skip_if_time_sensitive (void);
-
 int
 test_framework_skip_if_no_aws (void);
 
